@@ -36,6 +36,7 @@ class ArticleItem(scrapy.Item):
     comment_total_count = scrapy.Field()
     err_msg = scrapy.Field()
     content_type = scrapy.Field()
+    post_id = scrapy.Field()  # 所应平台的post id
 
 
 class ArticleCommentItem(scrapy.Item):
@@ -43,22 +44,49 @@ class ArticleCommentItem(scrapy.Item):
     domain_url = scrapy.Field()
     domain_id = scrapy.Field()
     domain_name = scrapy.Field()
-    post_url = scrapy.Field()
-    post_id = scrapy.Field()
+    post_url = scrapy.Field()  # post url
+    post_id = scrapy.Field()  # 所属对应平台的post id
     block_id = scrapy.Field()
-    comment_id = scrapy.Field()
-    url = scrapy.Field()
+    comment_id = scrapy.Field()  # 评论ID
+    url = scrapy.Field()  # 评论链接
     url_md5 = scrapy.Field()
-    like_count = scrapy.Field()
-    author = scrapy.Field()
-    content = scrapy.Field()
+    like_count = scrapy.Field()  # 点赞数
+    author = scrapy.Field()  # 评论作者
+    author_id = scrapy.Field()  # 评论作者ID，取可以定位到用户首页的ID
+    content = scrapy.Field()  # 评论文字内容
     article_html = scrapy.Field()
     other_info = scrapy.Field()
+    ip_label = scrapy.Field()  # 评论IP
     upload_oss = scrapy.Field()
+    download_video = scrapy.Field()
+    download_image = scrapy.Field()
     publish_date = scrapy.Field()
     created_date = scrapy.Field()
 
 
+class ArticleAuthorItem(scrapy.Item):
+    task_id = scrapy.Field()
+    block_id = scrapy.Field()   # 平台
+    url = scrapy.Field()   # 主页链接
+    url_md5 = scrapy.Field()
+    name = scrapy.Field()   # 昵称
+    avatar = scrapy.Field()   # 头像
+    describe = scrapy.Field()   # 个性签名
+    follow_count = scrapy.Field()   # 关注用户数
+    followers_count = scrapy.Field()   # 粉丝数
+    location = scrapy.Field()   # 地区
+    mobile = scrapy.Field()   # 手机号
+    sec_uid = scrapy.Field()
+    uid = scrapy.Field()   # 用户ID
+    unique_id = scrapy.Field()   # 唯一ID
+    age = scrapy.Field()   # 年龄
+    other_info = scrapy.Field()   # 其它
+    ip_label = scrapy.Field()   # IP标签
+    upload_oss = scrapy.Field()
+    register_date = scrapy.Field()
+    created_date = scrapy.Field()
+
+
 class PaperItem(scrapy.Item):
     task_id = scrapy.Field()
     domain_url = scrapy.Field()
@@ -79,18 +107,18 @@ class PaperItem(scrapy.Item):
     author = scrapy.Field()
     content = scrapy.Field()
     article_html = scrapy.Field()
-    lang = scrapy.Field()  # 正文语言
-    abstract_cn = scrapy.Field()  # 摘要
+    lang = scrapy.Field()   # 正文语言
+    abstract_cn = scrapy.Field()   # 摘要
     abstract_en = scrapy.Field()
-    keywords = scrapy.Field()  # 关键词
-    doi = scrapy.Field()  # DOI
-    year = scrapy.Field()  # 年份
-    quote = scrapy.Field()  # 引用
-    publish_source = scrapy.Field()  # 发布来源
-    publish_source_url = scrapy.Field()  # 发布来源URL
-    subject = scrapy.Field()  # 学科
-    pages = scrapy.Field()  # 页数
-    word_number = scrapy.Field()  # 字数
+    keywords = scrapy.Field()   # 关键词
+    doi = scrapy.Field()   # DOI
+    year = scrapy.Field()   # 年份
+    quote = scrapy.Field()   # 引用
+    publish_source = scrapy.Field()   # 发布来源
+    publish_source_url = scrapy.Field()   # 发布来源URL
+    subject = scrapy.Field()   # 学科
+    pages = scrapy.Field()   # 页数
+    word_number = scrapy.Field()   # 字数
     download_url = scrapy.Field()
     other_info = scrapy.Field()
     upload_oss = scrapy.Field()
@@ -133,7 +161,7 @@ def get_comment_item(response, post_result, block, uploadOss=True):
     item["upload_oss"] = uploadOss
     if post_result:
         item["post_url"] = post_result["url"]
-        item["post_id"] = post_result["_id"]
+        item["post_id"] = post_result["post_id"]
         item["upload_oss"] = post_result.get('upload_oss', False)
     if response:
         item["url"] = response.url
@@ -141,6 +169,18 @@ def get_comment_item(response, post_result, block, uploadOss=True):
     return item
 
 
+def get_article_author_item(response, author, block, uploadOss=True):
+    item = ArticleAuthorItem()
+    item["block_id"] = block["identification"]
+    item["upload_oss"] = uploadOss
+    if author:
+        item["upload_oss"] = author.get('upload_oss', False)
+    if response:
+        item["url"] = response.url
+        item["url_md5"] = hashlib.md5(response.url.encode("utf-8")).hexdigest()
+    return item
+
+
 def get_paper_item(response, source, block, parse=True, uploadOss=True):
     item = PaperItem()
     item["domain_url"] = block["domain_url"]
